@@ -96,6 +96,18 @@ options:
         only.
     type: bool
     default: false
+  only_ipv4:
+    description:
+      - Use only ipv4 addresses for ansible_host and ansible_ssh_host.
+      - Using I(only_ipv4) helps when running Ansible in a ipv4 only setup.
+    type: bool
+    default: false
+  server_filters:
+    description:
+      - A dictionary of server filter value pairs.
+      - Available parameters can be seen under https://docs.openstack.org/api-ref/compute/#list-servers
+    type: dict
+    default: {}
   show_all:
     description:
       - Whether all servers should be listed or not.
@@ -273,7 +285,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             clouds_yaml_path = self.get_option('clouds_yaml_path')
             config_files = openstack.config.loader.CONFIG_FILES
             if clouds_yaml_path:
-                config_files += clouds_yaml_path
+                config_files = clouds_yaml_path + config_files
 
             config = openstack.config.loader.OpenStackConfig(
                 config_files=config_files)
@@ -303,6 +315,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
 
             expand_hostvars = self.get_option('expand_hostvars')
             all_projects = self.get_option('all_projects')
+            server_filters = self.get_option('server_filters')
             servers = []
 
             def _expand_server(server, cloud, volumes):
@@ -349,7 +362,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                             all_projects=all_projects,
                             # details are required because 'addresses'
                             # attribute must be populated
-                            details=True)
+                            details=True,
+                            **server_filters)
                     ]:
                         servers.append(server)
                 except openstack.exceptions.OpenStackCloudException as e:
@@ -384,10 +398,17 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                  if address['OS-EXT-IPS:type'] == 'floating'),
                 None)
 
-            fixed_ip = next(
-                (address['addr'] for address in addresses
-                 if address['OS-EXT-IPS:type'] == 'fixed'),
-                None)
+            if self.get_option('only_ipv4'):
+                fixed_ip = next(
+                    (address['addr'] for address in addresses
+                     if (address['OS-EXT-IPS:type'] == 'fixed' and address['version'] == 4)),
+                    None)
+
+            else:
+                fixed_ip = next(
+                    (address['addr'] for address in addresses
+                     if address['OS-EXT-IPS:type'] == 'fixed'),
+                    None)
 
             ip = floating_ip if floating_ip is not None and not self.get_option('private') else fixed_ip
 
